AccessEvent class

Implementers

Constructors

AccessEvent({required Access access, required Request? request, List<MapEntry<String, dynamic>>? errors, BuildContext? context})

Properties

access ↔ Access
getter/setter pair
after ↔ Map<String, dynamic>?
getter/setter pair
before ↔ Map<String, dynamic>?
getter/setter pair
context ↔ BuildContext?
getter/setter pair
createTime → DateTime
final
errors ↔ List<MapEntry<String, dynamic>>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
request ↔ Request?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → AccessToken?
no setter
type ↔ DbOperationType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap([bool includeBeforeAfter = true]) → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited