AccessPoint class

TODO: Document

Inheritance

Constructors

AccessPoint(FutureOr<AccessEvent> accessBuilder(Request request, BuildContext context))

Properties

accessBuilder → FutureOr<AccessEvent> Function(Request request, BuildContext context)
final
context → BuildContext
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
preferredType → EndpointPreferredType?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBinding() → CallingBinding
inherited
createCalling(BuildContext context) → Calling
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCall(Request request) → FutureOr<AccessEvent>
override
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited