AuthRedirect class

Inheritance

Constructors

AuthRedirect({Key? key, required String authorized, required String unauthorized})
const

Properties

authorized → String
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unauthorized → String
final

Methods

build(BuildContext context) → Component
override
createBinding() → StatelessBinding
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited