CacheControl class

Inheritance

Constructors

CacheControl({Cacheability? cacheability, Revalidation? revalidation, Expiration? expiration, required Component child})
factory

Properties

cacheControl → CacheControlBuilder
final
child → Component
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addHeaders(Message response) → void
createBinding() → SingleChildCallingBinding
override
createCalling(BuildContext context) → Calling
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRequest(Request request, FutureOr<Message> childCalling(Request request)) → FutureOr<Message>
override
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited