CallTrigger class

Inheritance

Constructors

CallTrigger({required Component child, void responseTrigger(Message message)?, void requestTrigger(Request request)?, bool ensureResponded = false, bool ensureSent = false})

Properties

child → Component
finalinherited
ensureResponded → bool
final
ensureSent → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
requestTrigger → void Function(Request request)?
final
responseTrigger → void Function(Message message)?
Message maybe request or response
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBinding() → SingleChildCallingBinding
override
createCalling(covariant SingleChildCallingBinding context) → Calling
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited