ContentDelivery class

Inheritance

Constructors

ContentDelivery(String directory, {bool useWatch = true, bool cacheFiles = true, bool useLastModified = true, Future beforeLoad()?, Map<String, Uint8List> additional = const {}})

Properties

additional → Map<String, Uint8List>
final
beforeLoad → Future Function()?
final
cacheFiles → bool
final
directory → String
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useLastModified → bool
final
useWatch → bool
final

Methods

build(BuildContext context) → Component
override
createBinding() → StatelessBinding
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited