CronJob class

Inheritance

Constructors

CronJob({required CronTimePeriod timePeriod, required Future<Message?> onCall(Request request, CronTimePeriod period), bool resetPeriodOnExternalCall = true, bool allowExternal = false, String? name, GlobalKey<State<StatefulComponent>>? key})

Properties

allowExternal → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
name → String
final
onCall → Future<Message?> Function(Request request, CronTimePeriod period)
final
resetPeriodOnExternalCall → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timePeriod → CronTimePeriod
final

Methods

build(BuildContext context) → Component
override
createBinding() → StatelessBinding
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited