GateWithChild class abstract

Inheritance
Implementers

Constructors

GateWithChild({required Component child})

Properties

child → Component
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBinding() → SingleChildCallingBinding
override
createCalling(BuildContext context) → Calling
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRequest(Request request, FutureOr<Message> childCalling(Request request)) → FutureOr<Message>
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited