GeneratedRedirect class

Inheritance

Constructors

GeneratedRedirect({required FutureOr<String> generate(Request request)})

Properties

context → BuildContext
no setterinherited
generate → FutureOr<String> Function(Request request)
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
preferredType → EndpointPreferredType?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBinding() → CallingBinding
inherited
createCalling(BuildContext context) → Calling
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCall(Request request) → FutureOr<Message>
override
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited