IfNoneMatchMethod class

Inheritance

Constructors

IfNoneMatchMethod()

Properties

context ↔ BuildContext
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRequest(Request request) → ValidationRequest<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(covariant ValidationRequest<String> request, covariant String? data) → ValidationResult
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited