LastModifiedEndpointState<T extends StatefulEndpoint> class abstract

Inheritance

Constructors

LastModifiedEndpointState()

Properties

attached → bool
no setterinherited
component → T
no setterinherited
context → StatefulBinding
no setterinherited
db → DataAccess
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
key → GlobalKey<State<T>>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Component
override
initState() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCall(covariant ValidationRequest<DateTime> request) → FutureOr<ResponseWithLastModified>
override
onRequest(ValidationRequest<DateTime> request) → FutureOr<ResponseWithLastModified>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited