NotFoundException class

Inheritance

Constructors

NotFoundException([String? route])

Properties

hashCode → int
The hash code for this object.
no setterinherited
payload ↔ Map<String, dynamic>?
getter/setter pairinherited
route ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
no setteroverride
superType → Type
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited