RequestTrigger class

Inheritance

Constructors

RequestTrigger({required Component child, required void trigger(Request request)?, bool ensureResponded = false, Key? key})
const

Properties

child → Component
final
ensureResponded → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trigger → void Function(Request request)?
final

Methods

build(BuildContext context) → Component
override
createBinding() → StatelessBinding
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited