Response class

Inheritance
Implementers

Constructors

Response({required Request request, Body? body, required int statusCode, Map<String, dynamic>? additionalHeaders, ContentType? contentType})
Creates with subclasses

Properties

additionalHeaders ↔ Map<String, dynamic>?
getter/setter pair
agent → Agent
Request agent. Example: The agent of all http/(s) requests received by the server is Agent.http
no setterinherited
auth → AccessToken?
no setterinherited
body ↔ Body?
Request Body Http requests body or web socket messages "body" values In Cron Jobs body is empty
getter/setter pairinherited
cause → Cause
Request Cause. Indicates why this request is made.
no setterinherited
contentType ↔ ContentType?
getter/setter pairinherited-setteroverride-getter
context → RequestContext
RequestContext is context of request info about handling, creating, responding
finalinherited
fullPath → String
Request Full Path include host and scheme and query parameters examples : http request : https://localhost:9090/a/b?c=d web socket req. : ws://a/b?c=d internal req. : style://a/b?c=d
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
nextPathSegment → String
no setterinherited
path → PathController
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sent ↔ bool?
if sending operation not resulted sent is null if success, sent is true if operation failed, sent is false
getter/setter pair
statusCode ↔ int
getter/setter pair

Methods

ensureSent() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited