RevalidationMethod<T> class abstract

Implementers

Constructors

RevalidationMethod()

Properties

context ↔ BuildContext
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRequest(Request request) → ValidationRequest<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(ValidationRequest<T> request, T? data) → ValidationResult

Operators

operator ==(Object other) → bool
The equality operator.
inherited