Route class

Inheritance

Constructors

Route(String route, {bool handleUnknownAsRoot = false, Component? child, Component? root})

Properties

child → Component?
final
handleUnknownAsRoot → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
root → Component?
final
route → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Component
override
createBinding() → StatelessBinding
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited