Server class

Base component for server

Service is service owner that handle requests, hook states and necessary wrappers.

Server creates a gateway for handle requests. Server also wraps base services(http,ws,logger etc.).

Inheritance

Constructors

Server({GlobalKey<State<StatefulComponent>>? key, HttpService? httpService, WebSocketService? socketService, DataAccess? dataAccess, Crypto? cryptoService, Logger? logger, String? rootName, Component? rootEndpoint, Authorization? authorization, required List<Component> children, String? faviconDirectory, Map<Type, ExceptionEndpoint<Exception>>? defaultExceptionEndpoints})

Properties

authorization → Authorization?
final
children → List<Component>
final
cryptoService → Crypto?
final
dataAccess → DataAccess?
final
defaultExceptionEndpoints → Map<Type, ExceptionEndpoint<Exception>>
final
faviconDirectory → String?
final
hashCode → int
The hash code for this object.
no setterinherited
httpService → HttpService?
final
key → GlobalKey<State<StatefulComponent>>?
no setterinherited
logger → Logger
final
rootEndpoint → Component?
final
rootName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketService → WebSocketService?
final

Methods

createBinding() → StatefulBinding
inherited
createState() → State<StatefulComponent>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited