ServerBinding class

Inheritance
Mixed-in types

Constructors

ServerBinding(ServiceCallingComponent component)

Properties

ancestorCalling → CallingBinding?
no setterinherited
authorization → Authorization
no setterinherited
calling → Calling
no setterinherited
child → Binding
no setterinherited
component → ServiceCallingComponent
no setteroverride
cronJobs → Map<String, CronTimePeriod>
cronJobs took Cron Job route and their period.
finalinherited
crypto → Crypto
no setterinherited
dataAccess → DataAccess
no setterinherited
exceptionHandler → ExceptionHandler
no setterinherited
findCalling → CallingBinding
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
httpService → HttpService
no setterinherited
key → Key
Calling get calling;
no setterinherited
logger → Logger
no setterinherited
owner → ServerBinding
no setterinherited
rootEndpoint ↔ Binding
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceRootName ↔ String
Service root name used for redirect, connecting microservices and connecting remote services.
getter/setter pairinherited
socketService → WebSocketService
no setterinherited

Methods

addCronJob(String route, CronTimePeriod period) → void
inherited
addState(State<StatefulComponent> state) → void
Add states by key
inherited
attachToParent(Binding parent) → void
inherited
buildBinding() → void
override
callCronJob(String route, DateTime time) → Future<void>
inherited
callingVisitor(TreeVisitor<Calling> visitor) → TreeVisitor<Calling>
override
executeCronJobs() → void
Call first time
inherited
findAncestorBindingOfType<T extends Binding>() → T?
inherited
findAncestorComponentOfType<T extends Component>() → T?
inherited
findAncestorServiceByName<T extends ServerBinding>(String name) → T?
inherited
findAncestorStateOfKey<T extends GlobalKey<State<StatefulComponent>>>(String key) → T?
inherited
findAncestorStateOfType<T extends State<StatefulComponent>>() → T?
inherited
findChildService<T extends ServerBinding>() → T?
inherited
findChildState<T extends State<StatefulComponent>>() → T?
inherited
getPath() → String
Get current context path
inherited
hasService<T extends _BaseService>() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visitCallingChildren(TreeVisitor<Calling> visitor) → TreeVisitor<Calling>
inherited
visitChildren(TreeVisitor<Binding> visitor) → TreeVisitor<Binding>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited