SimpleDataAccess class

Inheritance

Constructors

SimpleDataAccess(String directory)

Properties

context → BuildContext
no setterinherited
data → Map<String, Map<String, Map<String, dynamic>>>
finalinherited
dataAccess ↔ DataAccess
latefinalinherited
directory ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregation(Access access) → FutureOr<ReadListResult>
inherited
any(AccessEvent event) → FutureOr<DbResult>
inherited
count(Access access) → FutureOr<DbResult<int>>
inherited
create(Access access) → FutureOr<CreateDbResult>
override
delete(Access access) → FutureOr<DeleteDbResult>
override
exists(Access access) → FutureOr<DbResult<bool>>
inherited
init([bool inInterface = true]) → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(Access access) → Future<ReadDbResult>
inherited
readList(Access access) → FutureOr<ReadListResult>
inherited
saveCollection(String collection) → Future<void>
toString() → String
A string representation of this object.
inherited
update(Access access) → FutureOr<UpdateDbResult>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited