SingleChildCallingComponent class abstract

Inheritance
Implementers

Constructors

SingleChildCallingComponent(Component child, {Key? key})

Properties

child → Component
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBinding() → SingleChildCallingBinding
override
createCalling(BuildContext context) → Calling
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited