StatefulEndpoint class abstract

Inheritance
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → GlobalKey<State<StatefulComponent>>?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBinding() → StatefulBinding
inherited
createState() → EndpointState<StatefulEndpoint>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toStringDeep() → String
inherited
toStringSort() → String
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited