StatelessBinding class

Inheritance
Implementers

Constructors

StatelessBinding(StatelessComponent component)

Properties

ancestorCalling → CallingBinding?
no setterinherited
authorization → Authorization
no setterinherited
child ↔ Binding?
getter/setter pairinherited
component → StatelessComponent
no setteroverride
crypto → Crypto
no setterinherited
dataAccess → DataAccess
no setterinherited
exceptionHandler → ExceptionHandler
no setterinherited
findCalling → CallingBinding
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
httpService → HttpService
no setterinherited
key → Key
Calling get calling;
no setteroverride
logger → Logger
no setterinherited
owner → ServerBinding
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketService → WebSocketService
no setterinherited

Methods

attachToParent(Binding parent) → void
inherited
build(Binding binding) → Component
override
buildBinding() → void
inherited
findAncestorBindingOfType<T extends Binding>() → T?
inherited
findAncestorComponentOfType<T extends Component>() → T?
inherited
findAncestorServiceByName<T extends ServerBinding>(String name) → T?
inherited
findAncestorStateOfKey<T extends GlobalKey<State<StatefulComponent>>>(String key) → T?
inherited
findAncestorStateOfType<T extends State<StatefulComponent>>() → T?
inherited
findChildService<T extends ServerBinding>() → T?
inherited
findChildState<T extends State<StatefulComponent>>() → T?
inherited
getPath() → String
Get current context path
inherited
hasService<T extends _BaseService>() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visitCallingChildren(TreeVisitor<Calling> visitor) → TreeVisitor<Calling>
inherited
visitChildren(TreeVisitor<Binding> visitor) → TreeVisitor<Binding>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited