ValidationRequest<T> class

Inheritance

Constructors

ValidationRequest.fromRequest(Request request, T? validationData, RevalidationMethod<T> revalidationMethod)

Properties

agent → Agent
Request agent. Example: The agent of all http/(s) requests received by the server is Agent.http
no setterinherited
arguments → Map<String, dynamic>
no setterinherited
auth → AccessToken?
no setterinherited
body ↔ Body?
Request Body Http requests body or web socket messages "body" values In Cron Jobs body is empty
getter/setter pairinherited
cause → Cause
Request Cause. Indicates why this request is made.
no setterinherited
contentType ↔ ContentType?
getter/setter pairinherited
context → RequestContext
RequestContext is context of request info about handling, creating, responding
finalinherited
cookies → List<Cookie>?
finalinherited
fullPath → String
Request Full Path include host and scheme and query parameters examples : http request : https://localhost:9090/a/b?c=d web socket req. : ws://a/b?c=d internal req. : style://a/b?c=d
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, List<String>>?
finalinherited
method ↔ Methods?
getter/setter pairinherited
nextPathSegment → String
no setterinherited
path → PathController
no setterinherited
responded ↔ bool?
if sending operation not resulted sent is null if success, sent is true if operation failed, sent is false
getter/setter pairinherited
revalidationMethod ↔ RevalidationMethod<T>
/
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ AccessToken?
getter/setter pairinherited
validationData ↔ T?
getter/setter pair

Methods

ensureResponded() → Future<bool>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
response(Body? body, {int? statusCode, Map<String, dynamic>? headers, ContentType? contentType}) → Response
inherited
toMap() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited
validate(T? value) → ValidationResult
Return true the client has valid data Not need sent data.

Operators

operator ==(Object other) → bool
The equality operator.
inherited